| Title: | Exploratory plots of Alaskan survey and fisheries data in support of stock assessment |
|---|---|
| Description: | Pulls in survey, observer and catch data from the Eastern Bering Sea, Northern Bering Sea, Aleutian Islands, and Gulf of Alaska and automates creation of plots for each groundfish species to understand time-varying, seasonal, and spatial aspects of these fish populations and fisheries. This package was created in support of Alaska stock assessment science to inform model specification and interpretation. |
| Authors: | Carey McGilliard [aut, cre] (ORCID: YOUR-ORCID-ID) |
| Maintainer: | Carey McGilliard <[email protected]> |
| License: | `use_mit_license()`, `use_gpl3_license()` or friends to pick a license |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-17 09:55:40 UTC |
| Source: | https://github.com/afsc-assessments/funplots |
Plot catches for each species by gear
plot_total_catch(thedata, year, species, area)plot_total_catch(thedata, year, species, area)
thedata |
catch data frame |
year |
latest year to include |
species |
species group code, e.g. "DUSK" found where |
area |
sample area "GOA", "AI" or "BS" (or combos) |
plot_total_catch(year = 2022,species = "DUSK",area = "GOA",db = akfin)plot_total_catch(year = 2022,species = "DUSK",area = "GOA",db = akfin)